@@ -264,13 +264,12 @@ class RestAPI(object):
 					id = subscription_plan['plan']['id']
 					try: subscriptions[email]["plans"][id]
 					except KeyError: subscriptions[email]["plans"][id] = {}
-					subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['id'],
-					subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id'],
-					subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname'],
-					subscriptions[email]["plans"][id]["plan_active_status"] = subscription_plan['plan']['active'],
+					subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['id']
+					subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id']
+					subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname']
+					subscriptions[email]["plans"][id]["plan_active_status"] = subscription_plan['plan']['active']
 
 			# success.
-			print(json.dumps(subscriptions, indent=4))
 			return r3sponse.success_response("Successfully retrieved the subscriptions.", {
 				"subscriptions":subscriptions,
 			})
